#ifndef LUM_WINDOWGROUP_H
#define LUM_WINDOWGROUP_H

/*
  This source is part of the Illumination library
  Copyright (C) 2004  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Base/Size.h>

#include <Lum/Menu.h>
#include <Lum/Object.h>

namespace Lum {

  class LUMAPI WindowGroup : public Group
  {
  private:
    MenuStrip *men;
    Object    *main;
    Object    *tool;
    Object    *status;
    bool      mainSeamless;

  public:
    WindowGroup();
    virtual ~WindowGroup();

    void SetMenuStrip(MenuStrip* menuStrip);
    void SetToolbar(Object* object);
    void SetMain(Object* object, bool seamless=false);
    void SetStatusLine(Object* object);

    bool VisitChildren(Visitor &visitor, bool onlyVisible);

    void CalcSize();
    void Layout();
  };
}

#endif
